berater
======
...

### Install
```pip install berater```


### Usage
```python
...
```

----
[![Build Status](https://travis-ci.org/dpep/berater_py.svg?branch=main)](https://travis-ci.org/dpep/berater_py)
[![Coverage Status](https://coveralls.io/repos/github/dpep/berater_py/badge.svg?branch=main)](https://coveralls.io/github/dpep/berater_py?branch=main)
[![installs](https://img.shields.io/pypi/dm/berater?label=installs)](https://pypi.org/project/berater)
